@@ -23,7 +23,7 @@ class PackageTemplater(Templater):
     template_url: str
     template_version: str
     template_commit: str
-    test_cases: list[str] = ["defaults"]
+    _test_cases: list[str] = ["defaults"]
     copyright_year: Optional[str] = None
     _target_dir: Optional[Path] = None
 
@@ -54,6 +54,24 @@ class PackageTemplater(Templater):
         t.copyright_year = cookiecutter_args["copyright_year"]
         return t
 
+    @property
+    def test_cases(self) -> list[str]:
+        """Return list of test cases.
+
+        The getter deduplicates the stored list before returning it.
+
+        Don't use `append()` on the returned list to add test cases to the package, as
+        the getter returns a copy of the list stored in the object."""
+        cases = []
+        for t in self._test_cases:
+            if t not in cases:
+                cases.append(t)
+        return cases
+
+    @test_cases.setter
+    def test_cases(self, test_cases: list[str]):
+        self._test_cases = test_cases
+
     def _cruft_renderer(
         self,
         template_location: str,
@@ -139,12 +157,19 @@ class PackageTemplater(Templater):
             extra_context=self.cookiecutter_args,
         )
 
-        self.commit(
+        updated = self.commit(
             "Update from template\n\n"
             + f"Template version: {self.template_version} ({self.template_commit[:7]})",
             init=False,
         )
 
-        click.secho(
-            f"{self.deptype.capitalize()} {self.name} successfully updated 🎉", bold=True
-        )
+        if updated:
+            click.secho(
+                f"{self.deptype.capitalize()} {self.name} successfully updated 🎉",
+                bold=True,
+            )
+        else:
+            click.secho(
+                f"{self.deptype.capitalize()} {self.name} already up-to-date 🎉",
+                bold=True,
+            )
